@@ -5,7 +5,7 @@ A_clere<-function(y=y,x=x,g=NULL,analysis="aic"){
    if(is.null(g)){
       g=min(5,ncol(x))#ncol(x)
    }
-   model <- clere::fit.clere(y = as.numeric(y), x = x, g = g, plotit = FALSE, analysis=analysis)
+   model <- clere::fitClere(y = as.numeric(y), x = x, g = g, plotit = FALSE, analysis=analysis)
    A=c(model@intercept,rowMeans(model@Bw))
    return(A)
 }
\ No newline at end of file
