@@ -11,7 +11,7 @@ cleanZlars<-function(Z = Z, X = X, methode = 1, mode=c("MSE","BIC"),intercept=TR
     Yloc = X[, i]
     larsloc=lars(x=as.matrix(Xloc),y=Yloc,type=select,intercept=intercept)
     B_loc=meilleur_lars(lars=larsloc,X=Xloc,Y=Yloc,mode=mode,intercept=intercept,K=K,groupe=groupe)$A
-    Z[qui,i][B_loc[-1]==0]=0#on rpercute les 0
+    Z[qui,i][B_loc[-1]==0]=0#on repercute les 0
   }
   return(Z)
 }
\ No newline at end of file
